API Reference
=============

This section provides detailed API documentation for all modules in the libadalina-core library.

.. toctree::
   :maxdepth: 2

   readers
   writers
   sedona_configuration
   sedona_utils
   spatial_operators
   graph_building

